@@ -44,6 +44,10 @@ def _compute_release_tags(revset_query):
     # XXX this may be a little bit too naive. But let's make things simple for a
     # first implementation.
 
+    for commit_desc in commit_desc_since_last_release.split("\n"):
+        if re.match(r"^\w+(\([^)]+\)|)!(\([^)]+\)|):", commit_desc):
+            return "major"
+
     if "break" in commit_desc_since_last_release:
         return "major"
     if "feat" in commit_desc_since_last_release:
@@ -247,9 +251,14 @@ def do_release(
             assignement.value[1].value = str(minor + 1)
 
         elif effective_release_type == "major":
-            assignement.value[2].value = "0"
-            assignement.value[1].value = "0"
-            assignement.value[0].value = str(major + 1)
+            # we only do major release if we have reached at least 1.0
+            if assignement.value[0].value != "0":
+                assignement.value[2].value = "0"
+                assignement.value[1].value = "0"
+                assignement.value[0].value = str(major + 1)
+            else:
+                assignement.value[2].value = "0"
+                assignement.value[1].value = str(minor + 1)
 
         elif effective_release_type == "calendar":
             today = date.today()
